#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <lct/utils.h>

/* from kbd 0.96 */
void* xmalloc(size_t n)
{
  void *p = malloc(n);
  if (p == NULL)
    {
      fprintf(stderr, "Out of Memory\n");
      exit(1);
    }
  return p;
}

char* xstrdup(char *p)
{
  char *q = strdup(p);
  if (q == NULL)
    {
      fprintf(stderr, "Out of Memory?\n");
      exit(1);
    }
  return q;
}
